@@ -29,4 +29,4 @@ class ShuJiu:
         return self.__name
 
     def toFullString(self):
-        return self.__name + "第" + str(self.__index) + "天"
+        return "%s第%d天" % (self.__name, self.__index)
