@@ -1,8 +1,7 @@
 # -*- coding: utf-8 -*-
-from datetime import timedelta
 from math import ceil
 
-from . import ExactDate, Solar
+from . import Solar
 from .util import SolarUtil
 
 
@@ -58,11 +57,7 @@ class SolarWeek:
         获取当前日期是在当月第几周
         :return: 周序号，从1开始
         """
-        first_day = ExactDate.fromYmd(self.__year, self.__month, 1)
-        first_day_week = first_day.isoweekday()
-        if 7 == first_day_week:
-            first_day_week = 0
-        offset = first_day_week - self.__start
+        offset = Solar.fromYmd(self.__year, self.__month, 1).getWeek() - self.__start
         if offset < 0:
             offset += 7
         return int(ceil((self.__day + offset) * 1.0 / 7))
@@ -72,11 +67,7 @@ class SolarWeek:
         获取当前日期是在当年第几周
         :return: 周序号，从1开始
         """
-        first_day = ExactDate.fromYmd(self.__year, 1, 1)
-        first_day_week = first_day.isoweekday()
-        if 7 == first_day_week:
-            first_day_week = 0
-        offset = first_day_week - self.__start
+        offset = Solar.fromYmd(self.__year, 1, 1).getWeek() - self.__start
         if offset < 0:
             offset += 7
         return int(ceil((SolarUtil.getDaysInYear(self.__year, self.__month, self.__day) + offset) * 1.0 / 7))
@@ -86,15 +77,11 @@ class SolarWeek:
         获取本周第一天的阳历日期（可能跨月）
         :return: 本周第一天的阳历日期
         """
-        date = ExactDate.fromYmd(self.__year, self.__month, self.__day)
-        week = date.isoweekday()
-        if week == 7:
-            week = 0
-        prev = week - self.__start
+        solar = Solar.fromYmd(self.__year, self.__month, self.__day)
+        prev = solar.getWeek() - self.__start
         if prev < 0:
             prev += 7
-        date = date + timedelta(days=-prev)
-        return Solar.fromDate(date)
+        return solar.next(-prev)
 
     def getFirstDayInMonth(self):
         """
@@ -138,16 +125,16 @@ class SolarWeek:
         """
         if 0 == weeks:
             return SolarWeek.fromYmd(self.__year, self.__month, self.__day, self.__start)
+        solar = Solar.fromYmd(self.__year, self.__month, self.__day)
         if separate_month:
             n = weeks
-            c = ExactDate.fromYmd(self.__year, self.__month, self.__day)
-            week = SolarWeek.fromDate(c, self.__start)
+            week = SolarWeek.fromYmd(solar.getYear(), solar.getMonth(), solar.getDay(), self.__start)
             month = self.__month
             plus = n > 0
             days = 7 if plus else -7
             while 0 != n:
-                c = c + timedelta(days=days)
-                week = SolarWeek.fromDate(c, self.__start)
+                solar = solar.next(days)
+                week = SolarWeek.fromYmd(solar.getYear(), solar.getMonth(), solar.getDay(), self.__start)
                 week_month = week.getMonth()
                 if month != week_month:
                     index = week.getIndex()
@@ -157,22 +144,19 @@ class SolarWeek:
                             week = SolarWeek.fromYmd(first_day.getYear(), first_day.getMonth(), first_day.getDay(), self.__start)
                             week_month = week.getMonth()
                         else:
-                            c = ExactDate.fromYmd(week.getYear(), week.getMonth(), 1)
-                            week = SolarWeek.fromDate(c, self.__start)
+                            solar = Solar.fromYmd(week.getYear(), week.getMonth(), 1)
+                            week = SolarWeek.fromYmd(solar.getYear(), solar.getMonth(), solar.getDay(), self.__start)
                     else:
-                        size = SolarUtil.getWeeksOfMonth(week.getYear(), week.getMonth(), self.__start)
-                        if size == index:
-                            first_day = week.getFirstDay()
-                            last_day = first_day.next(6)
+                        if SolarUtil.getWeeksOfMonth(week.getYear(), week.getMonth(), self.__start) == index:
+                            last_day = week.getFirstDay().next(6)
                             week = SolarWeek.fromYmd(last_day.getYear(), last_day.getMonth(), last_day.getDay(), self.__start)
                             week_month = week.getMonth()
                         else:
-                            c = ExactDate.fromYmd(week.getYear(), week.getMonth(), SolarUtil.getDaysOfMonth(week.getYear(), week.getMonth()))
-                            week = SolarWeek.fromDate(c, self.__start)
+                            solar = Solar.fromYmd(week.getYear(), week.getMonth(), SolarUtil.getDaysOfMonth(week.getYear(), week.getMonth()))
+                            week = SolarWeek.fromYmd(solar.getYear(), solar.getMonth(), solar.getDay(), self.__start)
                     month = week_month
                 n -= 1 if plus else -1
             return week
         else:
-            c = ExactDate.fromYmd(self.__year, self.__month, self.__day)
-            c = c + timedelta(days=weeks * 7)
-            return SolarWeek.fromDate(c, self.__start)
+            solar = solar.next(weeks * 7)
+            return SolarWeek.fromYmd(solar.getYear(), solar.getMonth(), solar.getDay(), self.__start)
